pub struct DarkTheme { /* private fields */ }Expand description
One sample theme which prefers dark colors from the color-palette and generates styles for widgets.
The widget set fits for the widgets provided by rat-widget, for other needs take it as an idea for your own implementation.
Implementations